import { DatabaseAdapter, JSObject, SyncDatabaseAdapter } from './database';
/**
 * JsonFileAdapter is an async adapter for working with Json Files
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 */
export declare class JsonFileAdapter implements DatabaseAdapter {
    /**
     * The path of the [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    readonly path: string;
    /**
     * The settings for the [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html): <br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    readonly settings: JsonAdapterSettings;
    /**
     * The constructor for [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html)
     *
     * @param path the path to a json file to save to and load from
     * @param settings The settings for the [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html):<br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    path: string, settings?: JsonAdapterSettingsInput);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    save(data: JSObject): Promise<void>;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) - 👩‍👦 the parent class
     */
    load(): Promise<JSObject>;
}
/**
 * [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) is an sync adapter for working with Json Files
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 */
export declare class SyncJsonFileAdapter implements SyncDatabaseAdapter {
    /**
     * The path of the [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    readonly path: string;
    /**
     * The settings for the [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html): <br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    readonly settings: JsonAdapterSettings;
    /**
     * The constructor for [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
     *
     * @param path the path to a json file to save to and load from
     * @param settings The settings for the [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html):<br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    path: string, settings?: JsonAdapterSettingsInput);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    save(data: JSObject): void;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html) - 👩‍👦 the parent class
     */
    load(): JSObject;
}
/**
 * The settings for [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) or
 * [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html):
 *   beautify - should the generated json be beautified (default: false)
 *   beautify_space - the space to indent the json with (default: 2)
 *
 * This is the input version of the interface. It gets applied all default values when passed to a
 * [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) or
 * [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 *
 * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html)
 * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
 */
export interface JsonAdapterSettingsInput {
    /**
     * Should the generated json be beautified?
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonAdapterSettingsInput](https://nsc-de.github.io/js-database/interfaces/_json_adapter_.jsonadaptersettingsinput.html) - 👩‍👦 the parent interface
     */
    beautify?: false;
    /**
     * How many spaces should be used to indent the generated json
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonAdapterSettingsInput](https://nsc-de.github.io/js-database/interfaces/_json_adapter_.jsonadaptersettingsinput.html) - 👩‍👦 the parent interface
     */
    beautify_space?: number;
}
/**
 * The settings for [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html) or
 * [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html):
 *   beautify - should the generated json be beautified (default: false)
 *   beautify_space - the space to indent the json with (default: 2)
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 *
 * @see [JsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.jsonfileadapter.html)
 * @see [SyncJsonFileAdapter](https://nsc-de.github.io/js-database/classes/_json_adapter_.syncjsonfileadapter.html)
 */
export interface JsonAdapterSettings {
    /**
     * Should the generated json be beautified?
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonAdapterSettings](https://nsc-de.github.io/js-database/interfaces/_database_.jsonadaptersettings.html) - 👩‍👦 the parent interface
     */
    beautify: false;
    /**
     * How many spaces should be used to indent the generated json
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     *
     * @see [JsonAdapterSettings](https://nsc-de.github.io/js-database/interfaces/_database_.jsonadaptersettings.html) - 👩‍👦 the parent interface
     */
    beautify_space: number;
}
