"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncXMLFileAdapter = exports.XMLFileAdapter = void 0;
var fs = __importStar(require("fs"));
var path = __importStar(require("path"));
var fs_help_1 = require("./fs_help");
var xml;
try {
    xml = require('xml-js');
}
catch (e) {
    var err = new Error("You should have installed xml-js if you want to use the xml-adapter");
    err.stack += '\nCaused by: ' + err.message + err.stack;
    throw e;
}
var XMLFileAdapter = (function () {
    function XMLFileAdapter(path, settings) {
        if (settings === void 0) { settings = {}; }
        this.path = path;
        this.settings = applyDefaults(settings);
    }
    XMLFileAdapter.prototype.save = function (data) {
        var _this = this;
        return new Promise(function (rs, rj) {
            return fs_help_1.mkdirs(path.dirname(_this.path)).then(function () {
                return fs.writeFile(_this.path, generateXML(data, _this.settings), function (err) {
                    if (err)
                        rj(err);
                    else
                        rs();
                });
            });
        });
    };
    XMLFileAdapter.prototype.load = function () {
        var _this = this;
        return new Promise(function (rs, rj) {
            fs.exists(_this.path, function (exists) {
                if (exists) {
                    fs.readFile(_this.path, function (err, data) {
                        if (err)
                            rj(err);
                        else
                            rs(parseXML(data.toString()));
                    });
                }
                else
                    rs({});
            });
        });
    };
    return XMLFileAdapter;
}());
exports.XMLFileAdapter = XMLFileAdapter;
var SyncXMLFileAdapter = (function () {
    function SyncXMLFileAdapter(path, settings) {
        if (settings === void 0) { settings = {}; }
        this.path = path;
        this.settings = applyDefaults(settings);
    }
    SyncXMLFileAdapter.prototype.save = function (data) {
        fs_help_1.mkdirsSync(path.dirname(this.path));
        fs.writeFileSync(this.path, generateXML(data, this.settings));
    };
    SyncXMLFileAdapter.prototype.load = function () {
        if (fs.existsSync(this.path))
            return parseXML(fs.readFileSync(this.path).toString());
        return {};
    };
    return SyncXMLFileAdapter;
}());
exports.SyncXMLFileAdapter = SyncXMLFileAdapter;
function simplify(arg) {
    if (Array.isArray(arg))
        return arg.map(function (e) { return simplify(arg); });
    if (typeof arg == "object") {
        if (arg._text)
            return arg._text;
        else {
            var keys = Object.keys(arg);
            for (var i = 0; i < keys.length; i++)
                arg[keys[i]] = simplify(arg[keys[i]]);
            return arg;
        }
    }
    return arg;
}
function applyDefaults(settings) {
    return {
        beautify: settings.beautify || true,
        beautify_space: settings.beautify_space || 2,
        fullTagEmptyElement: settings.fullTagEmptyElement || false,
        indentAttributes: settings.indentAttributes || false
    };
}
function parseXML(data) {
    return simplify(xml.xml2js(data, { compact: true }));
}
function generateXML(data, settings) {
    var args = {
        fullTagEmptyElement: settings.fullTagEmptyElement,
        indentAttributes: settings.indentAttributes,
        compact: true,
    };
    args.space = settings.beautify ? settings.beautify_space : 0;
    return xml.js2xml(data, args);
}
