import { DatabaseAdapter, JSObject, SyncDatabaseAdapter } from './database';
/**
 * YamlFileAdapter is an async adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 */
export declare class YamlFileAdapter implements DatabaseAdapter {
    readonly path: string;
    /**
     * The constructor for [YamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.yamlfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @param path the path to a yaml file to save to and load from
     *
     * @see [YamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.yamlfileadapter.html) - 👩‍👦 the parent class
     */
    constructor(path: string);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @see [YamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.yamlfileadapter.html) - 👩‍👦 the parent class
     */
    save(data: JSObject): Promise<void>;
    /**
     * Loads data from the file the adapter refers to
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @see [YamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.yamlfileadapter.html) - 👩‍👦 the parent class
     */
    load(): Promise<JSObject>;
}
/**
 * [SyncYamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.syncyamlfileadapter.html) is an sync adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
 */
export declare class SyncYamlFileAdapter implements SyncDatabaseAdapter {
    readonly path: string;
    /**
     * The constructor for [SyncYamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.syncyamlfileadapter.html)
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @param path the path to a yaml file to save to and load from
     *
     * @see [SyncYamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.syncyamlfileadapter.html) - 👩‍👦 the parent class
     */
    constructor(path: string);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @see [SyncYamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.syncyamlfileadapter.html) - 👩‍👦 the parent class
     */
    save(data: JSObject): void;
    /**
     * Loads data from the file the adapter refers to
     *
     * @author Nicolas Schmidt <[@nsc-de](https://github.com/nsc-de)>
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @see [SyncYamlFileAdapter](https://nsc-de.github.io/js-database/classes/_yaml_adapter_.syncyamlfileadapter.html) - 👩‍👦 the parent class
     */
    load(): JSObject;
}
